##################### Conditional Intensity Functions #########################
"""
Return the conditional intensity function of a point process as a `Proxy`.

If only a `model` and a `Record` are passed, calculates the CIF of the
process with parameters estimated from `Record`.

The specific model (Homogeneous Poisson, Inhomogeneous Poisson, Hawkes, etc...)
is determined by the type of `params`.

See [`Parameters`](@ref) [`Record`](@ref) [`Proxy`](@ref)

```@example
rec = Record("Resources/data/record.csv", "Resources/data/proxy.csv")
CIF("hp", rec) # CIF of a Poisson process with parameters estimated from `rec`
CIF(ParametersIP(1e-4, 2e-2), rec) # CIF of an Inhomogeneous Poisson process
```
"""
CIF(model::String, rec::Record) = CIF(estimate(model, rec), rec)
CIF(model::String, rec::Record, f::Interp) = CIF(estimate(model, rec, f), rec, f)

#----------------- Homogeneous Poisson ----------------------------------------
CIF(params::ParametersHP, rec::Record, _...) =
    linear_interpolation([rec.start; rec.finish], [params.μ; params.μ])

#---------------- Inhomgeneous Poisson ----------------------------------------
CIF(params::ParametersIP, _::Record, f::Interp) =
    linear_interpolation(get_xs(f), params.μ .+ (params.γ .* get_ys(f)))

#--------------- Homogeneous Hawkes -------------------------------------------
function CIF(params::ParametersHH, rec::Record, _...)
    kernel(t) = params.α * exp(-params.β * t) # Hawkes process kernel function
    Δ = minimum(diff(rec.events)) / 1000
    inter = diff([rec.start; rec.events])
    xs = Float64[]
    idxs = Int[]
    for i in 1:n_events(rec)
        xs_new = LinRange(Δ, inter[i], 100)
        xs = [xs; rec[i] .- reverse(xs_new)]
        idxs = [idxs; length(xs)]
    end
    vals = fill(params.μ, length(xs) + 1)
    for idx in idxs
        vals[1:idx-1] .+= kernel.(xs[idx] .- xs[1:idx-1])
    end

    return linear_interpolation([xs; rec.finish], vals)
end

#-------------- Inhomogeneous Hawkes ------------------------------------------
function CIF(params::ParametersIH, rec::Record, f::Interp)
    kernel(t) = params.α * exp(-params.β * t)
    Δ = minimum(diff(rec.events)) / 1000
    inter = diff([rec.start; rec.events])
    xs = Float64[]
    idxs = Int[]
    for i in 1:n_events(rec)
        xs_new = LinRange(Δ, inter[i], 100)
        xs = [xs; rec[i] .- reverse(xs_new)]
        idxs = [idxs; length(xs)]
    end
    xs = [xs; LinRange(xs[end] + Δ, rec.finish, 100)]
    vals = params.μ .+ (params.γ .* f(xs))
    for idx in idxs
        vals[1:idx-1] = vals[1:idx-1] .+ kernel.(xs[idx] .- xs[1:idx-1])
    end
    return linear_interpolation(xs, vals)
end

###################### ∫CIF ###################################################
"""
Calculates the integral of the conditional intensity function of a process.
``\\int_0^T \\lambda(t; \\theta) dt``
"""
∫CIF(model::String, rec::Record) = ∫CIF(estimate(model, rec), rec)
∫CIF(model::String, rec::Record, f::Interp) = ∫CIF(estimate(model, rec, f), rec, f)

#----------- Homogeneous Poisson ----------------------------------------------
∫CIF(params::ParametersHP, rec::Record, _...) = params.μ * span(rec)

#------------- Inhomogeneous Poisson ------------------------------------------
∫CIF(params::ParametersIP, rec::Record, f::Interp) =
    (params.μ * span(rec)) + (params.γ * ∫(f, interval(rec)...))

#----------- Homogeneous Hawkes -----------------------------------------------
function ∫CIF(params::ParametersHH, rec::Record, _...)
    ∫base = (params.μ * span(rec))
    ∫self = (params.α / params.β) * sum(1 .- exp.(-params.β .* (rec.finish .- rec.events)))
    return ∫base + ∫self
end

#-------------- Inhomogeneous Hawkes ------------------------------------------
function ∫CIF(params::ParametersIH, rec::Record, f::Interp)
    ∫base = (params.μ * span(rec))
    ∫f = (params.γ * ∫(f))
    ∫self = (params.α / params.β) * sum(1 .- exp.(-params.β .* (rec.finish .- rec.events)))
    return ∫base + +∫f + ∫self
end

