########################## Model - data type ##################################
"""
Abstract type for dispatching on the type of model.

Used in [`CIF`](@ref), [`simulate`](@ref), [`time_transform`](@ref).

Possible concrete subtypes:
- `HP` -> Homogeneous Poisson
- `IP` -> Inhomogeneous Poisson
- `HH` -> Homogeneous Hawkes
- `IH` -> Inhomogenous Hawkes
"""
abstract type Model end
struct HP <: Model end
struct HH <: Model end
struct IP <: Model end
struct IH <: Model end

"""
Converts a string to a model type. The string is case insensitive.
Possible choices:
"HP" -> Homogeneous Poisson
"IP" -> Inhomogeneous Poisson
"HH" -> Homogeneous Hawkes
"IH" -> Inhomogenous Hawkes
"""
function str2model(model::String)::Model
    model = lowercase(model)
    (model == "hp") && return HP()
    (model == "ip") && return IP()
    (model == "hh") && return HH()
    (model == "ih") && return IH()
    error("""No such model. Possible choices (case insensitive):
    "HP" -> Homogeneous Poisson
    "IP" -> Inhomogeneous Poisson
    "HH" -> Homogeneous Hawkes
    "IH" -> Inhomogenous Hawkes
    """)
end

########################## Distance - data type ###############################
"""
Abstract type for dispatching on the type of distance.

Used in [`time_transform`](@ref).

Possible concrete subtypes are:
- `KS` -> Kolmogorov-Smirnov distance
- `LP` -> ``Lp^2`` distance of the Laplace transforms
"""
abstract type Distance end
struct KS <: Distance end
struct LP <: Distance end
struct KSU <: Distance end

"""
Converts a string to a distance type. The string is case insensitive.

Used in [`distance`](@ref).

Possible choices for `dist` (case insensitive)
- "KS" -> KS type
- "LP" -> LP type
"""
function str2dist(dist::String)::Distance
    dist = lowercase(dist)
    (dist == "ks") && return KS()
    (dist == "lp") && return LP()
    (dist == "ksu") && return KSU()
    error("No such distance. Choose among 'KS', 'LP', and 'KSU'.")
end

########################## Parameters - data type #############################
"""
Abstract type for dispatching on the type of parameters.

Used in [`CIF`](@ref), [`simulate`](@ref), [`time_transform`](@ref).

Implemented methods for: `length`, `collect` and `show`.

Possible concrete subtypes are:
- `ParametersHP` -> Homogeneous Poisson    | 1 parameter  | μ
- `ParametersIP` -> Inhomogeneous Poisson  | 2 parameters | μ, γ
- `ParametersHH` -> Homogeneous Hawkes     | 3 parameters | μ, α, β
- `ParametersIH` -> Inhomogeneous Hawkes   | 4 parameters | μ, γ, α, β

Mostly initialized by the [`estimate`](@ref) function. But can be initialized
by providing the corresponding parameters.
```@example
rec = Record("Resources/data/record.csv")
params_hp = estimate("hp", rec) # ParametersHP
params_hh = PointProcessTools.ParametersHH(5e-5, 5e-5, 8e-5)
```
"""
abstract type Parameters{T} end
Base.length(params::Parameters) = length(fieldnames(typeof(params)))
Base.collect(params::Parameters) = [getfield(params, f) for f in fieldnames(typeof(params))]
Base.getindex(params::Parameters, n::Integer) = collect(params)[n]
function Base.show(io::IO, params::Parameters)
    fields = fieldnames(typeof(params))
    str = ""
    for field ∈ fields
        str *= string(field) * @sprintf " = %.3g - " getfield(params, field)
    end
    print(io, str[1:end-3])
end

struct ParametersHP{T<:AbstractFloat} <: Parameters{T}
    μ::T
end
ParametersHP(μ::Real) = ParametersHP(convert(AbstractFloat, μ))
Base.show(io::IO, ::MIME"text/plain", params::ParametersHP) =
    print(io, "Homogeneous Poisson process parameters\n", params)

struct ParametersIP{T<:AbstractFloat} <: Parameters{T}
    μ::T
    γ::T
end
ParametersIP(μ::Real, γ::Real) =
    ParametersIP(convert.(AbstractFloat, (μ, γ))...)

Base.show(io::IO, ::MIME"text/plain", params::ParametersIP) =
    print(io, "Inhomogeneous Poisson process parameters\n", params)

struct ParametersHH{T<:AbstractFloat} <: Parameters{T}
    μ::T
    α::T
    β::T
end
ParametersHH(μ::Real, α::Real, β::Real) =
    ParametersHH(convert.(AbstractFloat, (μ, α, β))...)
Base.show(io::IO, ::MIME"text/plain", params::ParametersHH) =
    print(io, "Homogeneous Hawkes process parameters\n", params)

struct ParametersIH{T<:AbstractFloat} <: Parameters{T}
    μ::T
    γ::T
    α::T
    β::T
end
ParametersIH(μ::Real, γ::Real, α::Real, β::Real) =
    ParametersIH(convert.(AbstractFloat, (μ, γ, α, β))...)
Base.show(io::IO, ::MIME"text/plain", params::ParametersIH) =
    print(io, "Inhomogeneous Hawkes process parameters\n", params)

