"""
Calculates the distance between the empirical distribution of the interarrival
times and an unit exponential distribution. It assumes `transf_events` are the
time transformed event times.

'dist' must be either "KS" for the Kolmogorov-Smirnov distance, or "Lp"  for the
distance using the Laplace transform (not case sensitive).

See [`time_transform`](@ref).

```@example
rec = Record("Resources/data/record.csv")
params_hh = ParametersHH(1e-4, 1e-4, 3e-4)
distance("ks", time_transform(params_hh, rec))
distance("Lp", time_transform(params_hh, rec))
```

For the Kolmogorov-Smirnov distance, the [Wikipedia article](https://en.wikipedia.org/wiki/Kolmogorov%E2%80%93Smirnov_test)
is sufficient.

For the Laplace distance, see [this paper](https://www.tandfonline.com/doi/abs/10.1080/02331880212042).
"""
distance(dist::String, transf::Vector{<:Real}) = distance(str2dist(dist), transf)
distance(dist::String, transf::Vector{<:Real}, ∫f::Real) =
    distance(str2dist(dist), transf, ∫f)

#---------------- Kolmogorov-Smirnov distance ---------------------------------
function distance(_::KS, transf::Vector{<:Real}, _...)
    diffs = sort(diff(transf))
    xs, vals = ecdf(diffs)
    dist_lower = maximum((1.0 .- exp.(-xs)) .- vals[1:end-1]) # Largest distance to lower part of step function
    dist_upper = maximum(vals[2:end] .- (1.0 .- exp.(-xs))) # Largest distance to upper part of step function
    return max(dist_lower, dist_upper)
end

#--------------- Laplace distance ---------------------------------------------
function distance(_::LP, transf::Vector{<:Real}, _...)
    isempty(transf) && return 1.0
    LIMIT = 5.0
    STEP = 0.01
    X = sort(diff(transf))
    N = length(X)
    points = 0.0:STEP:LIMIT
    integral = 0
    for point in points
        integral += STEP * (exp(-point) * ((sum(exp.(-(X .* point))) / N) - # The empirical Laplace transform
                                           (1.0 / (1.0 + point)))^2.0) # The Laplace transform of the exponential distribution (λ / (s + λ))
    end
    return integral
end

#------- Kolmogorov-Smirnov for uniform distribution ---------------------------
function distance(_::KSU, X::Vector{<:Real}, ∫f::Real)
    xs, vals = ecdf(X)
    dist_lower = maximum((xs ./ ∫f) .- vals[1:end-1]) # Largest distance to lower part of step function
    dist_upper = maximum(vals[2:end] .- (xs ./ ∫f)) # Largest distance to upper part of step function
    return max(dist_lower, dist_upper)
end

#--------------- ecdf --------------------------------------------------------
function ecdf(X::Vector{<:Real})
    xs = unique(X)
    ecdf = [0; map(x -> count(x .>= X) / length(X), xs)]
    return xs, ecdf
end
