#------------------ General -------------------
"""
Estimate the parameters of an observed process as one of the supported models.

The 'model' may be provided either as a string or as an instance of the model type.

For the homogeneous Poisson model, the maximum likelihood estimator (MLE) can be
calculated directly ([Laub (2021)](https://doi.org/10.1007/978-3-030-84639-8)).

For inhomogeneous Poisson, the MLE is approximated using a newtonian optimization
method.

For both variants of the Hawkes process, the MLE is approximated with an
expectation maximization (EM) algorithm ([E. Lewis, G. Mohler (2011)](https://api.semanticscholar.org/CorpusID:2105771)).  
Returns an instance of `Parameters`.

See [`Model`](@ref), [`Parameters`](@ref), [`Record`](@ref).

```@example
rec = Record("Resources/data/record.csv")
estimate("hp", rec) # Estimate the parameters for a Poisson process
estimate("hh", rec) # Estimate the parameters for a Hawkes process
```
"""
estimate(model_str::String, rec::Record) = estimate(str2model(model_str), rec)
estimate(model_str::String, rec::Record, f::Interp) = estimate(str2model(model_str), rec, f)

#------------------ Homogeneous Poisson ---------------------------------------
estimate(_::HP, rec::Record, _...) = ParametersHP(n_events(rec) / span(rec))
estimate(_::HP, events::Vector{<:Real}, T::Real, _...) = ParametersHP(length(events) / T)

#------------------ Inhomogeneous Poisson -------------------------------------
estimate(model::IP, rec::Record, f::Interp) =
    estimate(model, rec.events, span(rec), f, ∫(f, rec.start, rec.finish))

function estimate(_::IP, events::Vector{<:Real}, T::Real, f::Interp, ∫f::Real)
    f_times = f(events)
    initial_x = [length(f_times) / T, length(f_times) / T]
    lower = [0.0, 0.0]
    upper = [Inf, Inf]
    results = optimize(x -> objective_ip(x, f_times, ∫f, T),
        (stor, x) -> gradient_ip!(stor, x, f_times, ∫f, T),
        (stor, x) -> hessian_ip!(stor, x, f_times),
        lower, upper, initial_x, IPNewton())
    return ParametersIP(Optim.minimizer(results)[1], Optim.minimizer(results)[2])
end

function objective_ip(x, f_times, ∫f, T)
    return (x[1] * T) + (x[2] * ∫f) - # integral of the CIF 
           sum(log.(x[1] .+ (x[2] .* f_times))) # Sum of log of f at event times
end

function gradient_ip!(storage, x, f_times, ∫f, T)
    storage[1] = T - sum(1.0 ./ (x[1] .+ (x[2] .* f_times)))
    storage[2] = ∫f - sum(f_times ./ (x[1] .+ (x[2] .* f_times)))
end

function hessian_ip!(storage, x, f_times)
    storage[1, 1] = sum(1.0 ./ ((x[1] .+ (x[2] .* f_times))) .^ 2.0)
    storage[1, 2] = sum(f_times ./ ((x[1] .+ (x[2] .* f_times))) .^ 2.0)
    storage[2, 1] = storage[1, 2]
    storage[2, 2] = sum((f_times .^ 2) ./ ((x[1] .+ (x[2] .* f_times))) .^ 2.0)
end

#------------------ Homogeneous Hawkes ----------------------------------------
estimate(model::HH, rec::Record, _...) = estimate(model, rec.events, span(rec))

function estimate(_::HH, events::Vector{<:Real}, T::Real, _...)
    N = length(events)
    step_tol = 1e-4
    max_iter = 500
    c1 = 0.2 + (0.6 * rand())
    c2 = 0.1 + (0.8 * rand())
    theta_new = ([c1, (1 - c1), log(10) * c2]) # This initial guess is compatible with the number of observations 
    theta_old = ([Inf, Inf, Inf])
    events_norm = (events .* (N / T))
    lambda_events = zeros(N) # Value of CIF at each event
    iter = 1
    while (sum(abs.(theta_old .- theta_new)) >= step_tol) && (iter < max_iter)# Stop iteration when optimization is smaller then tolerance 
        iter += 1
        copyto!(theta_old, theta_new) # New parameters become old
        α_old = theta_old[2] * theta_old[3]
        lambda_events[N] = 0.0 # Value of CIF at each event
        @inbounds for i in N-1:-1:1
            lambda_events[i] = exp(-theta_old[3] * (events_norm[i+1] - events_norm[i])) * (1.0 + lambda_events[i+1])
        end
        lambda_events .= theta_old[1] .+ (α_old .* lambda_events)
        D = 0.0 # Expected number of descendants
        div = 0.0
        @inbounds for i ∈ 1:N-1
            @inbounds for j ∈ i+1:N
                diffs = events_norm[j] - events_norm[i]
                p_D = (α_old * exp(-theta_old[3] * diffs)) / lambda_events[i] # Probability that event i triggered event j
                div += (diffs * p_D)
                D += p_D
            end
        end
        theta_new .= [1.0 - (D / N), D / N, D / div]
    end
    return ParametersHH(theta_new[1] * (N / T),
        theta_new[2] * theta_new[3] * (N / T),
        theta_new[3] * (N / T))
end

#------------------ Inhomogeneous Hawkes --------------------------------------
estimate(model::IH, rec::Record, f::Interp) =
    estimate(model, rec.events, span(rec), f, ∫(f, rec.start, rec.finish))

function estimate(_::IH, events::Vector{<:Real}, T::Real, f::Interp, ∫f::Real)
    f_times = f(events)
    N = length(events)
    events_norm = events .* (N / T)
    step_tol = 1e-4
    max_iter = 500
    c1 = 0.2 + (0.6 * rand())
    c2 = 0.1 + (0.8 * rand())
    theta_new = [c1 / 2, c1 / 2, (1 - c1), log(10) * c2]
    theta_old = [Inf, Inf, Inf, Inf]
    iter = 1
    lambda_events = zeros(N) # Value of intensity function at each event
    while (sum(abs.(theta_old - theta_new)) >= step_tol) && (iter < max_iter)# Stop iteration when optimization is smaller then tolerance 
        iter = iter + 1
        copyto!(theta_old, theta_new) # New parameters become old         
        α_old = theta_old[3] * theta_old[4]
        lambda_events[N] = 0.0
        @inbounds for i in N-1:-1:1
            lambda_events[i] = exp(-theta_old[4] * (events_norm[i+1] - events_norm[i])) * (1 + lambda_events[i+1])
        end
        @. lambda_events = (theta_old[1] + (theta_old[2] * f_times)) + (α_old * lambda_events)
        D = 0.0 # Expected number of descendants
        I = 0.0 # Expected number of immigrants
        I_base = 0.0 # Expected number of immigrants from the base intensity
        div = 0.0
        @inbounds for i in 1:N-1 # Go though each event calculating the probabilities of being an immigrand oor a descendant
            D_i = 0.0 # Probability that ti is a descendant
            p_ij = 0.0
            @inbounds for j in i+1:N
                diffs = events_norm[j] - events_norm[i]
                p_ij = (α_old * exp(-theta_old[4] * diffs)) / lambda_events[i] # Probability that event j triggered event i
                div += (diffs * p_ij)
                D_i += p_ij
            end
            D += D_i
            I += 1 - D_i
            I_base += (1 - D_i) * (theta_old[1] / (theta_old[1] + (theta_old[2] * f_times[i])))
        end
        theta_new .= [I_base / N, ((I - I_base) * T) / (∫f * N), D / N, D / div]
    end
    return ParametersIH(theta_new[1] * (N / T),
        theta_new[2] * (N / T),
        theta_new[3] * theta_new[4] * (N / T),
        theta_new[4] * (N / T))
end
