#---------------------- Goodness-of-fit test --------------------
"""
Performs the goodness-of-fit test for a given model and distance function. The 
number of simulations used in the bootstrap can be set with the `n_sims` keyword
argument (default 1000).

The `model` may be provided either as a string or as an instance of the model type.
The `dist` may be provided either as a string or as an instance of the distance type.

For inhomogeneous processes, the `proxy` field of `rec` must not be `nothing`.

Returns a named tuple with fields:
- `p`         -> returned p-value of the test
- `sim_dists` -> simulated distances used in calculating the p-value
- `dist`      -> distance between the observed and the estimated process
- `params`    -> estimated parameters of the model
See [`Record`](@ref) [`distance`](@ref) [`Model`](@ref) [`simulate`](@ref) [`estimate`](@ref)

```@example
rec = Record("Resources/data/record.csv")
fit_test("hp", "ks", rec) # Perform the goodness-of-fit test for a Poisson process using the KS-distance
fit_test("hh", "lp", rec; n_sims=1000) # Perform the test for a Hawkes process using the Laplace distance.
```
"""
function fit_test(model::Model, dist::Distance, rec::Record,
    f::Union{Nothing,Interp}=nothing; n_sims::Int=1000)
    ∫f = integral(f, interval(rec)...)
    ∫fT = ∫(f)
    params = estimate(model, rec.events, span(rec), f, ∫fT) # Estimate parameters via MLE
    d = distance(dist, time_transform(params, rec.events, rec.start, ∫f))
    d_sim = zeros(n_sims)
    # Threads.@threads for i in shuffle(1:n_sims) # For each of the simulated processes
    for i in 1:n_sims # For each of the simulated processes
        sim = simulate(params, rec.start, rec.finish, f)
        sim_params = estimate(model, sim, span(rec), f, ∫fT) # Estimate parameters via MLE
        d_sim[i] = distance(dist, time_transform(sim_params, sim, rec.start, ∫f))
    end
    p_value = sum(d_sim .> d) / n_sims
    return (p=p_value, sim_dists=d_sim, dist=d, params=params)
end

function fit_test(model_str::String, dist_str::String, rec::Record,
    f::Union{Nothing,Interp}=nothing; n_sims::Int=1000)
    return fit_test(str2model(model_str), str2dist(dist_str), rec, f, n_sims=n_sims)
end

