#----------------------- Homogeneous Poisson -----------------------
"""
Calculates the likelihood of as observed process with respect to the given parameters.

This function is dispatched on the type of 'params'.

See [`Parameters`](@ref) [`Record`]@ref.
"""
function likelihood(params::ParametersHP, rec::Record, _...)
    return n_events(rec) * ((params / span(rec)) - log(params.μ))
end
# WARN: is this correct?

#----------------------- Inhomogeneous Poisson -----------------------
function likelihood(params::ParametersIP, rec::Record, f::Interp)
    return (params.μ * n_events(rec)) + (params.γ * ∫(f)) - # Integral of the CIF
           sum(log.(params.μ .+ (params.γ .* f(rec.events)))) # Sum of log of CIF at event times
end

#----------------------- Homogeneous Hawkes -----------------------
function likelihood(params::ParametersHH, rec::Record, _...)
    A = zeros(n_events(rec)) # Vector A in Ozaki paper calculated recursively
    for i in n_events(rec)-1:-1:1
        A[i] = exp(-params.β * (rec[i+1] - rec[i])) * (1 + A[i+1])
    end
    return (params.μ * span(rec)) + # Integral of base rate
           ((params.α / params.β) * sum(1 .- exp.(-params.β .* (span(rec) .- rec.events)))) - # Integral of each kernel
           sum(log.(params.μ .+ (params.α .* A))) # Value of intensity at each event
end

#----------------------- Inhomogeneous Hawkes -----------------------
function likelihood(params::ParametersIH, rec::Record, f::Interp)
    A = zeros(n_events(rec)) # Vector A in Ozaki paper calculated recursively
    for i in n_events(rec)-1:-1:1
        A[i] = exp(-params.β * (rec[i+1] - rec[i])) * (1 + A[i+1])
    end
    return (params.μ * span(rec)) + (params.γ * ∫(f)) + # Integral of base rate
           ((params.α / params.β) * sum(1 .- exp.(-params.β .* (span(rec) .- rec.events)))) - # Integral of each kernel
           sum(log.(params.μ .+ (params.γ .* f(rec.events)) .+ (params.α .* A))) # Value of intensity at each event
end

#----------------------- AIC -------------------------------
"""
Calculates the Akaike Information Criterion for a given record and parameters.

This function is dispatched on the type of 'params'.

See [`likelihood`](@ref) [`Parameters`](@ref) [`Record`]@ref.
"""
function AIC(rec::Record, params::Parameters)
    return (2 * length(params)) - (2 * likelihood(rec, params))
end

function AIC(model::String, rec::Record)
    params = estimate(model, rec)
    return AIC(rec, params)
end
