#################### Proxy - data type ########################################
Interp = Interpolations.Extrapolation

"""
Proxy

Is a continuous function constructed by linearly interpolating the proxy values.
The actual data type of a Proxy is `Interp`, which is an alias for `Interpolations.
Extrapolation` (from the `Interpolations` package), but the `Proxy` function acts
as a constructor.

Implemented functions: `show`, `minimum`, `maximum`, `get_xs`, `get_ys`, `-`,
`interval`, `integral`, `∫`.

To initialize, a path to a csv file can be provided. The file must contain the
times of each observation in the first column and the values of each observation
in the second. Look in the `Resources/data` folder for an example.
```@example
Proxy("Resources/data/proxy.csv")
```

There are two keyword arguments: `period` and `shift`.

`period` is for calculating the finite central difference of the function.

`shift` is for shifting the function backwards or forwards.
```@example
-Proxy("Resources/data/proxy.csv", period=10000, shift=5000)
```

Instead of a file, is possible to initialize a `Proxy` with the values columns
of the file as `Vector`s.
```@example
-Proxy([0:1000:1000000], rand(1000))
```

Optionally, an interval can be passed too. Either one number, representing the 
total time span of the proxy, or two number, representing the start and end of
the interval where the proxy is defined.
`Interval`.
```@example
Proxy("Resources/data/proxy.csv", 500000)
Proxy("Resources/data/proxy.csv", 100000, 300000)
```
"""
Proxy(f_path::String; kwargs...) = Proxy(f_path, 0, Inf; kwargs...)
Proxy(f_path::String, T::Real; kwargs...) = Proxy(f_path, 0, T; kwargs...)

Proxy(xs::Vector{<:Real}, f_arr::Vector{<:Real}; kwargs...) =
    Proxy(xs, f_arr, 0, Inf; kwargs...)
Proxy(xs::Vector{<:Real}, f_arr::Vector{<:Real}, T::Real; kwargs...) =
    Proxy(xs, f_arr, 0, T; kwargs...)

function Proxy(f_path::String, start::Real, finish::Real; kwargs...)
    xs, arr_f = import_f(f_path)
    Proxy(xs, arr_f, start, finish; kwargs...)
end

function Proxy(xs::Vector{<:Real}, f_arr::Vector{<:Real}, start::Real, finish::Real; kwargs...)
    @assert length(xs) == length(f_arr) "Tie points and values for Proxy do not have the same length"
    @assert any((xs .>= start) .& (xs .<= finish)) "No measurements inside the interval."
    (:period ∈ keys(kwargs)) ? period = kwargs[:period] : period = 0
    (:shift ∈ keys(kwargs)) ? shift = kwargs[:shift] : shift = 0
    (:normalize ∈ keys(kwargs)) ? normalize = kwargs[:normalize] : normalize = true
    xs, f_arr = diff_f(xs, f_arr, start, finish, period, shift)
    ((:normalize ∉ keys(kwargs)) || (kwargs[:normalize])) && (normalize!(f_arr))
    return linear_interpolation(convert.(AbstractFloat, xs),
        convert.(AbstractFloat, f_arr))
end

Proxy(f::Interp, T::Real; kwargs...) = Proxy(get_xs(f), get_ys(f), 0, T; kwargs...)
Proxy(f::Interp, start::Real, finish::Real; kwargs...) =
    Proxy(get_xs(f), get_ys(f), start, finish; kwargs...)

"""
Constructs a proxy with the shape of a square function. It takes only the values
``0`` and ``1``, where the switching between the values occurs at times `changes`.
"""
square_proxy(changes::Vector{<:Real}, T::Real) =
    square_proxy(changes, 0, T)

function square_proxy(changes::Vector{<:Real}, start::Real, finish::Real)
    changes = unique(sort(changes[start<=changes<=finish]))
    Δ = minimum(diff(changes)) / 1e6
    before = changes .- Δ
    after = changes .+ Δ
    xs = unique(sort([start; before; after; finish]))
    f_arr = ones(length(xs))
    for i ∈ 3:length(f_arr)
        f_arr[i] = 1 - f_arr[i-2]
    end
    return Proxy(xs, f_arr, start, finish)
end

"Returns the tie points of the interpolation"
get_xs(f::Interp) = collect(knots(f))
"Returns the value at each tie point of the interpolation"
get_ys(f::Interp) = f(get_xs(f))
Base.minimum(f::Interp) = minimum(get_ys(f))
Base.maximum(f::Interp) = maximum(get_ys(f))
Base.show(io::IO, ::MIME"text/plain", f::Interp) =
    print(io, "Proxy for a point process\n", f)
Base.show(io::IO, f::Interp) =
    print(io, @sprintf "Proxy over interval (%.3g, %.3g)." start(f) finish(f))
"Inverts and renormalizes the function. Use `normalize=false` if renormalization is not desired"
Base.:-(f::Interp; normalize=true) =
    Proxy(get_xs(f), -1 .* get_ys(f), normalize=normalize)
"Returns the interval in which the function is defined."
interval(f::Interp) = (get_xs(f)[1], get_xs(f)[end])
start(f::Interp) = get_xs(f)[1]
finish(f::Interp) = get_xs(f)[end]

"""
The cummulative integral function of ``f``. If ``f`` is the a function over
``[0, T]``.

Returns the function ``g(t) = \\int_0^t f(t) dt`` is returned.
"""
function integral(f::Interp, start::Real, finish::Real)
    xs_f = filter(x -> start <= x <= finish, get_xs(f))
    xs = sort(union(xs_f, collect(LinRange(start, finish, 10000))))
    vals = zeros(length(xs))
    for i in length(vals)-1:-1:1
        vals[i] = vals[i+1] + ((f(xs[i]) + f(xs[i+1])) * (xs[i+1] - xs[i]) / 2)
    end
    return linear_interpolation(convert.(AbstractFloat, xs),
        convert.(AbstractFloat, vals))
end
integral(f::Interp) = integral(f, interval(f)...)
integral(::Nothing, _...) = nothing

"""
The integral of ``f`` over the whole interval ``[a, b]``.

Returns the value ``\\int_a^b f(f) dt``.
"""
function ∫(f::Interp, start::Real, finish::Real)
    xs = union(get_xs(f), start, finish)
    ∫f = 0
    for i in length(xs)-1:-1:1
        ∫f += ((f(xs[i]) + f(xs[i+1])) * (xs[i+1] - xs[i]) / 2)
    end
    return ∫f
end
∫(f::Interp) = ∫(f, interval(f)...)
∫(::Nothing, _...) = nothing

############################### helper functions ##############################
"""
Helper function for instantiating a `Proxy`.

Reads a CSV file and returns two vectors: one are the tie points for the
interpolations, the other are the values in each tie point.

Also calculated the finite central differences and the shift, if necessary.
"""
function import_f(file_path::String)
    delta_table = CSV.read(file_path, DataFrame; header=1)
    sort!(delta_table, 1)
    age = delta_table[:, 1]
    val = delta_table[:, 2]
    n_reps = 0
    for i in 1:length(age)-1
        n = 1
        sum_rep = val[i]
        while age[i+n-1] == age[i+n]
            splice!(age, i + n)
            sum_rep += splice!(val, i + n)
            n += 1
            n_reps += 1
        end
        val[i] = sum_rep / n
    end
    if n_reps > 0
        @info "$(n_reps) repeated ages found in the external function record."
    end
    return age, val
end

"Auxiliary file for testing. Returns a non-normalized function"
function function_from_file(file_path::String)
    age, val = import_f(file_path)
    return linear_interpolation(convert.(AbstractFloat, age),
        convert.(AbstractFloat, val))
end

"Helper function to calculate the finite central difference and shift of a proxy."
function diff_f(xs::Vector{<:Real}, vals::Vector{<:Real}, start::Real, finish::Real,
    period::Real, shift::Real)
    new_fin = finish == Inf ? maximum(xs) : finish
    @assert any(xs .<= start) && any(xs .>= new_fin) "Function is not defined for the whole interval"
    p = sortperm(xs)
    xs .= xs[p]
    vals .= vals[p]
    all(xs .> start) && @warn "Proxy not defined in the beginning of the interval. Values from $(start) to $(xs[1]) were extrapolated."
    all(xs .< new_fin) && @warn "Proxy not defined in the end of the interval. Values from $(xs[end]) to $(new_fin) were extrapolated."
    if period != 0
        xs1 = xs .+ period / 2
        xs2 = xs .- period / 2
        xs_new = sort(union(xs1, xs2, start - shift, new_fin - shift))
        f1 = linear_interpolation(xs1, vals, extrapolation_bc=Line())(xs_new)
        f2 = linear_interpolation(xs2, vals, extrapolation_bc=Line())(xs_new)
        f_new = f1 - f2
    else
        xs_new = sort(union(xs, start - shift, new_fin - shift))
        f_new = linear_interpolation(xs, vals, extrapolation_bc=Line())(xs_new)
    end
    xs_new .+= shift
    idxs = (xs_new .>= start) .& (xs_new .<= new_fin)
    return xs_new[idxs], f_new[idxs]
end

"Helper function to normalize a vector to have min=0 and max=1"
function normalize!(vec::Vector{<:Real})
    M = maximum(vec)
    m = minimum(vec)
    if M == m
        vec .= 1.0
    else
        vec .-= m
        vec ./= M - m
    end
    return vec
end


