############################### Record - data type #######################
"""
Record
- `events::Vector{<:AbstractFloat}` -> Event history of the process
- `interval::Interval` -> Time window of the observation

Represents an observed process. Event times represent time before present,
therefore the present in represented as 0 and positive values represent past
events. If negative values are passed, they will be converted to positive.

Implemented functions: `show`, `events_to_array`, `n_events`, `length`,
`interval`, `start`, `finish`, `getindex`.

The events can either be in a csv file and the path to it provided to the
constructor or passed directly as a `Vector`. For a csv file, first column must
contain the times of the events and it must contain a header. Look at the folder
`Resources/data` for an example.

```@example
Record("Resources/data/record.csv")
Record([1, 4, 5, 5.5, 8, 8.9])
```

An interval can be provided in the last positions.
```@example
Record("Resources/data/record.csv", "Resources/data/proxy.csv", 100000, period=10000)
Record([1, 4, 5, 5.5, 8, 8.9], [0, 2, 4, 6, 8, 10], [1, 2, 5, 4, 7, 3], 200000, 500000)
```

For csv files, if the file contains addtional categorical columns, keyword
arguments can be passed to filter the desired events. Provide the pair 
`col=[val1, val2, ..., valn]` to keep only events whose value in column `col`
is any of the values `val1`, `val2`, ..., `valn`.
```@example
Record("Resources/data/record.csv", Composition=["Mafic", "Bimodal"])
```
"""
struct Record{T<:AbstractFloat} <: AbstractArray{T,1}
    events::Vector{T}
    start::T
    finish::T

    Record(rec::String; kwargs...) = Record(rec, 0, Inf; kwargs...)
    Record(rec::String, T::Real; kwargs...) = Record(rec, 0, T; kwargs...)
    Record(rec::Vector{<:Real}; _...) = Record(rec, 0, Inf)
    Record(rec::Vector{<:Real}, T::Real; _...) = Record(rec, 0, T)

    function Record(rec_path::String, start::Real, finish::Real; kwargs...)
        table = CSV.read(rec_path, DataFrame; header=1)
        rename!(table, names(table) .=> (strip.(names(table))))
        for (key, value) in kwargs
            if string(key) in names(table)
                table = filter(row -> row[string(key)] ∈ value, table)
                for val ∈ value
                    if !any(map(x -> x == val, table[!, string(key)]))
                        @info "No entry in column $(string(key)) has value $(string(val))."
                    end
                end
            else
                @info "Column name '$(string(key)) ' not found in '$(rec_path)'. This input was ignored."
            end
        end
        events = table.Age
        Record(events, start, finish)
    end

    function Record(rec_arr::Vector{<:Real}, start::Real, finish::Real; _...)
        all(rec_arr .<= 0) && (rec_arr = sort(-rec_arr))
        events = filter(x -> start <= x <= finish, rec_arr)
        if length(events) != length(unique(events))
            @info "There are $(length(events) - 
                  length(unique(events))) events with duplicated ages."
            unique!(events)
        end
        @assert length(events) > 0 "There are no events in this interval."
        sort!(events)
        new_start = convert(AbstractFloat, start)
        new_finish = convert(AbstractFloat, (finish == Inf) ? maximum(events) : finish)
        new{typeof(new_start)}(convert.(AbstractFloat, events), new_start, new_finish)
    end
end

Base.show(io::IO, ::MIME"text/plain", rec::Record) =
    print(io, "Record\n", rec)
Base.show(io::IO, rec::Record) =
    print(io, @sprintf "%d events over interval (%.3g, %.3g). Average rate of %.3g events / unit of time" n_events(rec) rec.start rec.finish n_events(rec) / span(rec))

Base.getindex(rec::Record, i::Int) = rec.events[i]
Base.getindex(rec::Record, I::Vararg{Int}) = [rec[i] for i in I]
Base.size(rec::Record) = (length(rec.events),)
Base.IndexStyle(::Type{<:Record}) = IndexLinear()

"Returns the number of events of the record."
n_events(rec::Record) = length(rec)

"Returns the interval of time where the record is defined"
interval(rec::Record) = (rec.start, rec.finish)
"Returns the total length of time of the interval where the record is defined"
span(rec::Record) = rec.finish - rec.start

"Transforms the events into a ``0-1`` array with legth equal to the `Record`'s interval."
events_to_array(rec::Record) = events_to_array(rec.finish .- rec.events, length(rec))
function events_to_array(events::Vector{<:Real}, T::Real)
    arr = zeros(Int(ceil(T)) + 1)
    arr[Int.(round.(events .+ 1))] .= 1
    return arr
end


