#------------------------- Homogeneous Poisson ----------------
"""
Simulate one realization of a point process with the given parameters and interval.

This function is dispatched on the type of 'params'. For inhomogeneous processes,
a `Proxy` object is required to provide the intensity function.

Returns a vector containing the event times.

See [`Parameters`](@ref), [`Record`](@ref), [`Proxy`](@ref).

```@example
simulate(ParametersHP(1), 0, 100) # Simulates a Poisson process with unit intensity over [0, 100]
params_ih = ParametersIH(1, 4, 2, 4)
proxy = Proxy(collect(0:100), log.(0:100))
simulate(params_ih, 0, 100, proxy) # Simualte a Inhomogeneous Hawkes process
```
"""
function simulate(μ::Real, start::Real, finish::Real) # Used also by the other models
    T = finish - start
    rec = randexp(ceil(Int, 1.3 * T * μ))
    cumsum!(rec, rec)
    while rec[end] < T * μ
        append!(rec, rec[end] + randexp())
    end
    rec .*= (1.0 / μ)
    return rec[rec.<=T] .+ start
end
simulate(μ::Real, T::Real) = simulate(μ, 0, T)
simulate(params::Parameters, T::Real, args...) = simulate(params, 0, T, args...)

#---------------- Homogeneous Poisson ----------------------------------------
simulate(params::ParametersHP, start::Real, finish::Real, _...) =
    simulate(params.μ, start, finish)

#---------------- Inhomogeneous Poisson ------------------------
simulate(params::ParametersIP, start::Real, finish::Real, f::Interp) =
    sort([simulate(params.μ, start, finish); thinning(simulate(params.γ, start, finish), f)])

#--------------- Homogeneous Hawkes ------------------------------
function simulate(params::ParametersHH, start::Real, finish::Real, _...)
    sim_μ = simulate(params.μ, start, finish)
    return sort([sim_μ; generate_descendants(sim_μ, start, finish, params.α, params.β)])
end

#--------------- Inhomogenous Hawkes ----------------------------
function simulate(params::ParametersIH, start::Real, finish::Real, f::Interp)
    sim_base = simulate(ParametersIP(params.μ, params.γ), start, finish, f)
    return sort([sim_base;
        generate_descendants(sim_base, start, finish, params.α, params.β)])
end

#---------------------- Auxiliary -----------------------
"""
Implements the thinning algorithm.
[Lewis (1979)](https://doi.org/10.1002/nav.3800260304)
"""
function thinning(rec::Vector{<:Real}, CIF::Interp)
    return rec[rand(length(rec)).<=CIF(rec)]
end

"""
Generates the descendants of a Hawkes process from the events generated from the
baseline intensity (the `parents`).

The idea is to recurse over the generations. The offspring of the current `parents`
will become the next parents until some generation does not produce any offspring.

For each event in `parents`, new events are generated as an inhomogeneous Poisson
process with the activation function.
"""
function generate_descendants(parents::Vector{S}, start::S, finish::S,
    α::S, β::S) where {S<:AbstractFloat}
    descendants = S[]
    next_gen = parents
    while ~isempty(next_gen)
        last_gen = copy(next_gen)
        next_gen = S[]
        for parent in last_gen
            sim_transf = simulate(1.0,
                (α / β) * (1.0 - exp(-β * (finish - parent)))) # Simulate a homogeneous Poisson process
            append!(next_gen, (parent .-
                               ((-1.0 / β) .* log.(1.0 .- ((β / α) .* sim_transf))))) # Inverse transform to get the inhomogeneous Poisson process
        end
        append!(descendants, next_gen)
    end
    return descendants[descendants.>=start]
end

generate_descendants(parents::Vector, start::Real, finish::Real, α::Real, β::Real) =
    generate_descendants(convert.(AbstractFloat, parents),
        convert(AbstractFloat, start),
        convert(AbstractFloat, finish),
        convert(AbstractFloat, α),
        convert(AbstractFloat, β))
