# --------------- Test for simulation algorithms ------------------------
"""
Tests the simulation algorithm for a given model and record.

The function simulates the model `n_sims` times with the parameters estimated
from the provided `Record` and compares the expected cummulative number of events
over the process interval with the average cummulative number of events generated
by the simulations.

Instead of a model as a first argument, it is possible to provide parameters.

The function plots both curves and their difference to visually compare if there
is a significantdiscrepancy between the two.

The function is dispatched based on the type of 'params'.
See [`simulate`](@ref) [`Parameters`](@ref) [`Record`](@ref)

```@example
rec = Record("Resources/data/record.csv")
test_simulation("hh", rec)
test_simulation(ParametersHP(1e-4), rec, n_sims=1000, plot_results=true)
```
"""
function test_simulation(model::String, rec::Record, f::Union{Nothing,Interp}=nothing;
    n_sims::Integer=1000, plot_results::Bool=true)
    return test_simulation(estimate(model, rec, f),
        rec, f, n_sims=n_sims, plot_results=plot_results)
end

function test_simulation(params::Parameters, rec::Record, f::Union{Nothing,Interp}=nothing
    ; n_sims::Integer=1000, plot_results::Bool=true)
    expected_arrivals = get_expected(params, rec, integral(f, interval(rec)...))
    mean_arrivals = zeros(1000)
    xs = LinRange(rec.start, rec.finish, 1000)
    for _ in 1:n_sims
        simulation = simulate(params, rec, f)
        for i in eachindex(mean_arrivals)
            mean_arrivals[i] += sum(simulation .>= xs[1001-i])
        end
    end
    mean_arrivals ./= n_sims
    if plot_results
        plot_sim_test(mean_arrivals, expected_arrivals)
    end
    return mean_arrivals, expected_arrivals
end

"""
Helper function for `test_simulation`. Calculates the expected number of
events at each time point.
"""
function get_expected(μ::ParametersHP, rec::Record, _...)
    return μ .* collect(LinRange(0, span(rec), 1000))
end

function get_expected(params::ParametersIP, rec::Record, ∫f::Interp)
    xs = collect(LinRange(rec.start, rec.finish, 1000))
    return (params.μ .* xs) .+ (params.γ .* ∫f(reverse(xs)))
end

# For HH and IH it is not so easy to calculate the expected number of events
# in each instant. This is a rough estimate.
function get_expected(params::ParametersHH, rec::Record, _...)
    return collect(LinRange(0,
        (params.μ * span(rec)) / (1 - (params.α / params.β)),
        1000))
end

function get_expected(params::ParametersIH, rec::Record, ∫f::Interp)
    xs = collect(LinRange(rec.start, rec.finish, 1000))
    return ((params.μ .* (xs .- rec.start)) +
            (params.γ .* ∫f(reverse(xs)))) ./
           (1 - (params.α / params.β))
end

"""
Helper function for `test_simulation`. Plots the results of the simulation test.
"""
function plot_sim_test(mean_arrivals::Vector{<:Real}, expected_arrivals::Vector{<:Real})
    @printf "Average number of events per simulation: %.3g\n" mean_arrivals[end]
    @printf "Maximum departure from theoretical expectation: %.3g\n" maximum(abs.(mean_arrivals .- expected_arrivals))
    p1 = plot(mean_arrivals, label="Mean from simulations")
    plot!(expected_arrivals, label="Theoretical expectation")
    p2 = plot(mean_arrivals .- expected_arrivals, label="Mean - Theoretical")
    display(plot(p1, p2, layout=(1, 2), size=(800, 400)))
end

# ----------------------- Tests for estimation algorithms ----------------------
"""
Tests the estimation algorithm for a given model and record.

The function simulates `n_estimations` processes with parameters estimated from
the provided `Record` and estimates the parameters from the simulations.

Instead of a model as a first argument, it is possible to provide parameters.

The function then plots the histogram of the distribution of the estimated
parameters and the true parameters.

The function is dispatched based on the type of 'params'.

See [`estimate`](@ref) [`Parameters`](@ref) [`Record`](@ref)

```@example
rec = Record("Resources/data/record.csv")
test_estimation("hh", rec)
test_estimation(ParametersHP(1e-4), rec; n_estimations=1000, plot_results=true)
```

"""
function test_estimation(model::String, rec::Record, f::Union{Nothing,Interp}=nothing
    ; n_estimations::Integer=1000, plot_results::Bool=true)
    return test_estimation(estimate(model, rec, f), rec, f,
        n_estimations=n_estimations, plot_results=plot_results)
end

function test_estimation(params::Parameters, rec::Record, f::Union{Nothing,Interp}=nothing
    ; n_estimations::Integer=1000, plot_results::Bool=true)
    isa(params, ParametersHP) && (model = HP())
    isa(params, ParametersIP) && (model = IP())
    isa(params, ParametersHH) && (model = HH())
    isa(params, ParametersIH) && (model = IH())
    T = span(rec)
    estimations = zeros(n_estimations, length(params))
    mean_events = 0.0
    for i in 1:n_estimations
        simulation = simulate(params, rec, f)
        mean_events += length(simulation)
        estimations[i, :] .= estimate(model, simulation, T, f, ∫(f))
    end
    mean_events /= n_estimations
    if plot_results
        plot_est_test(params, estimations)
        @printf "Averge number of events in the simulations: %.3g\n" mean_events
    end
    return estimations, mean_events
end

"""
Helper function for `test_estimation` to plot the results of the estimation test.
"""
function plot_est_test(params, estimations)
    n = length(params)
    h = Vector(undef, n)
    for i in 1:n
        h[i] = histogram(estimations[:, i], label="Estimated $((fieldnames ∘ typeof)(params)[i])'s")
        vline!(h[i], [params[i]], label="True $((fieldnames ∘ typeof)(params)[i])")
    end
    display(plot(h..., layout=(1, n), xrotation=30, size=(300 * n, 300), bottom_margin=0.5Plots.cm))
    mean_est = mean(estimations, dims=1)
    err_perc = 100 .* (mean_est' .- params) ./ params
    for i in 1:n
        print("Parameter $(fieldnames(typeof(params))[i])\n")
        @printf "True parameter        - %2e\n" params[i]
        @printf "Estimated parameter   - %2e\n" mean_est[i]
        @printf "Error                 - %2e (%.2f%%)\n\n" (mean_est[i] - params[i]) err_perc[i]
    end
end

#---------------------- Test for goodness of fit algorithm ---------------------------
"""
Tests the goodness of fit algorithm for a given model and record.

Given a specific `model_type` and `dist_type`, the function estimates the
parameters of `rec` as the given model type and simulates `n_tests` processes
with these parameters. The function then runs the goodness-of-fit test on each
of these simulations and collects the `n_tests` p-values.

The p-values are returned and, if the `plot_results` keyword is set to true, the
function plots the distribution of the p-values. A distribution of p-values close
to uniform means that the test is working correctly.

See [`fit_test`](@ref) [`Model`](@ref) [`distance`](@ref) [`Record`](@ref)

```@example
rec = Record("Resources/data/record.csv", "Resources/data/proxy.csv")
fit_test("ip", "ks", rec) # Test the goodness-of-fit test for Poisson
fit_test("ih", "lp", rec; n_sims=1000, n_tests=1000, plot_results=true)
```
"""
function test_fit_test(model_type::Model, dist_type::Distance,
    params::Parameters, start::Real, finish::Real, f::Union{Nothing,Interp}=nothing;
    n_sims::Integer=1000, n_tests::Int=1000, plot_results::Bool=true)
    p_values = zeros(n_tests)
    for i in 1:n_tests
        sim = Record(simulate(params, start, finish), start, finish)
        p_values[i], _, _, _ = fit_test(model_type, dist_type, sim, f, n_sims=n_sims)
    end
    if plot_results
        plot_bootstrap_test(p_values)
    end
    return p_values
end

function test_fit_test(model_type::Model, dist_type::Distance, rec::Record,
    f::Union{Nothing,Interp}=nothing;
    n_sims::Integer=1000, n_tests::Int=1000, plot_results::Bool=true)
    params = estimate(model_type, rec)
    return test_fit_test(model_type, dist_type, params, rec.start, rec.finish, f,
        n_sims=n_sims, n_tests=n_tests, plot_results=plot_results)
end

function test_fit_test(model_str::String, dist_str::String, rec::Record,
    f::Union{Nothing,Interp}=nothing;
    n_sims::Integer=1000, n_tests::Int=1000, plot_results::Bool=true)
    return test_fit_test(str2model(model_str), str2dist(dist_str), rec, f,
        n_sims=n_sims, n_tests=n_tests, plot_results=plot_results)
end

"""
Helper function for `test_fit_test` to plot the results of the goodness-of-fit test.
"""
function plot_bootstrap_test(p_values)
    p = histogram(p_values,
        bins=0:0.05:1,
        normalized=:probability,
        label="Observed")
    hline!([0.05], lw=2, color=:red, label="Expected")
    xlims!(0, 1)
    ylabel!("Distribution")
    xlabel!("p-values")
    title!("Distribution of $(length(p_values)) p-values")
    display(p)
end

function plot_bootstrap(sim_dists, dist)
    xlim = maximum([sim_dists; dist]) * 1.05
    histogram(sim_dists,
        normalized=:probability,
        label="Simulated")
    vline!([dist], lw=2, color=:red, label="Empirical")
    xlims!(0, xlim)
    ylims!(0, ylims()[2])
    ylabel!("Distribution")
    xlabel!("Distance")
    title!("$(length(sim_dists)) distances")
end

##------------------ Test Time Transform --------------------------------------
"""
Tests the time transformation algorithm for a given model and record.

The function estimates the parameters of the model based on the given
data in `Record` and simulates 'n_sims' processes with these parameters.

The function then transforms the simulated processes plots the average empirical
pdf and cdf of the time transformed interarrival times of the simulations. If
the algorithm is correct, the distribution of these interarrival times should be
a unit exponential.

Notice that we are always using the same known parameters, therefore we know
exactly what the distribution of the time transformed events should be. 

See [`time_transform`, `Model`, `Record`](@ref)
"""
test_time_transform(model_str::String, rec::Record, f::Union{Nothing,Interp}=nothing
    ; n_sims::Integer=1000) =
    test_time_transform(str2model(model_str), rec, f, n_sims=n_sims)

function test_time_transform(model_type::Model, rec::Record,
    f::Union{Nothing,Interp}=nothing; n_sims::Integer=10000)
    params = estimate(model_type, rec, f)
    mean_ecdf = zeros(1000)
    xs = LinRange(0, 6, 1000)
    for i in 1:n_sims
        sim = simulate(params, rec)
        sample = sort(diff(time_transform(params, sim, rec.start, rec.finish, integral(f))))
        N = length(sample)
        for i in eachindex(mean_ecdf)
            mean_ecdf[i] += sum(sample .<= xs[i]) / N
        end
    end
    mean_ecdf ./= n_sims
    p1 = plot(xs, mean_ecdf, label="Empirical", lw=2, ylim=(0, 1))
    plot!(p1, xs, (1 .- exp.(-xs)), label="Theretical", lw=2, linestyle=:dash)
    p2 = plot(xs, mean_ecdf .- (1 .- exp.(-xs)), label="Empirical - Theoretical", lw=2)
    p = plot(p1, p2, xlim=(0, 6), size=(800, 300))
    display(p)
end

