#------------------ Homogeneous Poisson ---------------------------------------
"""
Returns the time transformed event history of the process given the conditional
intensity function calculated with respect to the given parameters. Used in
[`distance`](@ref) for calculating the KS or Laplace distances.

The function is dispatched based on the type of 'params'.

See [`Parameters`](@ref) [`Record`](@ref)

```@example
rec = Record("Resources/data/proxy.csv")
params = ParametersHH(1e-4, 1e-4, 2e-4)
time_transform(params, rec)
```
"""
time_transform(params::ParametersHP, rec::Record, _...) =
    time_transform(params.μ, rec.events, rec.start)

time_transform(params::ParametersHP, rec::Vector{<:Real}, start::Real, _...) =
    (rec .- start) .* params.μ

# For the other models to use
time_transform(μ::Real, rec::Vector{<:Real}, start::Real, _...) =
    (rec .- start) .* μ

#------------------ Inhomogeneous Poisson -------------------
function time_transform(params::ParametersIP, rec::Record, f::Interp)
    return time_transform(params, rec.events, rec.start, integral(f))
end

function time_transform(params::ParametersIP, rec::Vector{<:Real},
    start::Real, ∫f::Interp)
    rec = [start; rec]
    return cumsum((params.μ .* diff(rec)) .+ (params.γ .* -diff(∫f(rec))))
end

#------------------ Homogeneous Hawkes -------------------
function time_transform(params::ParametersHH, rec::Record, _...)
    return time_transform(params, rec.events, rec.start)
end

function time_transform(params::ParametersHH, rec::Vector{<:Real},
    start::Real, _...)
    diff_rec = diff([start; rec])
    N = length(diff_rec)
    A = zeros(N + 1) # Array A in Ozaki paper calculated recursively
    for i in N:-1:1
        A[i] = exp(-params.β * diff_rec[i]) * (1 + A[i+1])
    end
    # display(plot(plot((rec .- interval.a) .* params.μ), plot(((params.α / params.β) .* ((1.0:N) .+ A[2:N+1] .- A[1])))))
    return ((rec .- start) .* params.μ) .+ # Integral of base rate
           ((params.α / params.β) .* ((1.0:N) .+ A[2:N+1] .- A[1])) # Integral of each previous activation
end

#------------------ Inhomogeneous Hawkes -------------------
function time_transform(params::ParametersIH, rec::Record, f::Interp)
    return time_transform(params, rec.events, rec.start, integral(f))
end

function time_transform(params::ParametersIH, rec::Vector{Float64},
    start::Real, ∫f::Interp)
    return time_transform(ParametersHH(params.μ, params.α, params.β), rec, start) .+
           time_transform(ParametersIP(0.0, params.γ), rec, start, ∫f)
end

