#-------------------- Plotting Records -----------------------
"""
Plot recipes for multiple types of objects. Supported:
- `Record` -> Plots the event history as a stem plot. If the field '.f' is not
              nothing, plot also the normalized proxy.
- `Proxy` -> Plots the normalized proxy as a line plot.
- `Record` + `Parameters` -> Plots the event history and the conditional
                             intensity function in two subplots.
Keyword arguments:
- `spacing` -> Spacing between x-ticks.
- `smoothing` -> Tuple with the type of smoothing and the smoothing parameter
                 to be applied to the event history.
                 Can be "None", "Gaussian" or "Moving average".
"""
@recipe function f(rec::Record; spacing=100000, smoothing=("None", 0))
    x_ticks = collect(spacing*ceil(-rec.finish / spacing):spacing:spacing*floor(-rec.start / spacing))
    size --> (1200, 400)
    bottom_margin --> 1Plots.cm
    xlims --> -[rec.finish, rec.start]
    legend --> false
    xlabel --> "Time (kyr)"
    xticks --> (x_ticks, Int.(x_ticks ./ 1000))
    labels --> "Events"
    xrotation --> 45
    if lowercase(smoothing[1]) ∈ ["gaussian", "normal"]
        history = smooth_events(rec, smoothing[2])
        lw --> 2
        title --> "Gaussian smoothing of event history 
                   (σ = $(Int(round(smoothing[2] / 1000))) kyr)"
        ylabel --> "Events"
        ylims --> (0, maximum(history))
        x = Int.(round.(LinRange(-rec.finish, -rec.start, 10000)))
        x, history[Int.(round.(x .+ rec.finish .+ 1))]
    elseif lowercase(smoothing[1]) ∈ ["movavg", "movmean", "moving average"]
        lw --> 2
        history, window_width = movmean_events(-rec.events .+ span(rec), span(rec), smoothing[2])
        title --> "$(Int(window_width / 1000)) kyr moving average of event history"
        ylabel --> "Events / $(Int(window_width / 1000)) kyr"
        ylims --> (0, maximum(history))
        x = Int.(round.(LinRange(-rec.finish, -rec.start, 10000)))
        x, history[Int.(round.(x .+ rec.finish .+ 1))]
    else
        title --> "Event history"
        ylims --> (0, 1)
        yticks --> []
        line := :stem
        marker := :none
        -rec.events, ones(n_events(rec))
    end
end

@recipe function f(rec::Record, f::Interp; spacing=100000, smoothing=("None", 0))
    x_ticks = collect(spacing*ceil(-rec.finish / spacing):spacing:spacing*floor(-rec.start / spacing))
    size --> (1200, 400)
    bottom_margin --> 1Plots.cm
    xlims --> -[rec.finish, rec.start]
    legend --> false
    xlabel --> "Time (kyr)"
    xticks --> (x_ticks, Int.(x_ticks ./ 1000))
    labels --> "Events"
    xrotation --> 45
    left_margin --> 0.7Plots.cm
    layout := @layout [proxy{1.0w,0.7h}; events]
    link := :x
    @series begin
        title --> "Event history and proxy"
        seriestype := :line
        subplot := 1
        labels --> "Normalized proxy"
        lw --> 2
        ylims --> (0, 1)
        ylabel --> "Proxy value"
        yticks --> (0:0.25:1, 0:0.25:1)
        xaxis := false
        xticks := []
        -get_xs(f), get_ys(f)
    end
    @series begin
        subplot := 2
        color --> 2
        labels --> "Event history"
        ylabel --> "Events"
        yticks --> []
        xlabel --> "Time (kyr)"
        xticks --> (x_ticks, Int.(round.(x_ticks ./ 1000)))
        if lowercase(smoothing[1]) ∈ ["gaussian", "normal"]
            seriestype := :line
            lw --> 2
            history = smooth_events(rec, smoothing[2])
            x = Int.(round.(LinRange(-rec.finish, -rec.start, 10000)))
            x, history[Int.(round.(Int, x .+ rec.start .+ 1))]
        elseif lowercase(smoothing[1]) ∈ ["movavg", "movmean", "moving average"]
            seriestype := :line
            lw --> 2
            history = movmean_events(-rec.events .+ span(rec), span(rec), smoothing[2])
            x = Int.(round.(LinRange(-rec.start, -rec.finish, 10000)))
            x, history[Int.(round.(x .+ rec.start .+ 1))]
        else
            line := :stem
            marker := :none
            -rec.events, ones(n_events(rec))
        end
    end
end

#-------------------- Plotting Proxy -----------------------
@recipe function f(proxy::Interp; spacing=100000)
    int = interval(proxy)
    x_ticks = collect(spacing*ceil(-int[2] / spacing):spacing:spacing*floor(-int[1] / spacing))
    title --> "Normalized Proxy"
    lw --> 2
    xrotation --> 45
    size --> (1200, 400)
    bottom_margin --> 1Plots.cm
    left_margin --> 0.7Plots.cm
    xlims --> reverse(int)
    xlabel --> "Time (kyr)"
    xticks --> (x_ticks, Int.(x_ticks ./ 1000))
    y_max = maximum(proxy) * 1.1
    y_min = max(minimum(proxy) - (0.1 * y_max), 0)
    ylims --> (y_min, y_max)
    ylabel --> "Value"
    yticks --> LinRange(y_min, y_max, 5)
    legend --> false
    -get_xs(proxy), get_ys(proxy)
end

#-------------------- Plotting Record + Parameters -----------------------
@recipe function f(params::Parameters, rec::Record, f::Union{Nothing,Interp}=nothing;
    spacing=100000, smoothing=("None", 0))
    x_ticks = collect(spacing*ceil(-rec.start / spacing):spacing:spacing*floor(-rec.finish / spacing))
    cif = CIF(params, rec, f)
    m = minimum(cif)
    M = maximum(cif)
    size --> (1200, 400)
    bottom_margin --> 0.7Plots.cm
    left_margin --> 0.7Plots.cm
    xlims --> -[rec.finish, rec.start]
    layout := @layout [cif{1.0w,0.7h}; events]
    link := :x
    legend --> false
    @series begin
        title --> "Event history and estimated intensity function"
        seriestype := :line
        subplot := 1
        labels --> "CIF"
        lw --> 2
        ylims --> (0.9 * m, 1.1 * M)
        ylabel --> "Events / year"
        xaxis := false
        xticks := []
        -get_xs(cif), get_ys(cif)
    end
    @series begin
        subplot := 2
        color --> 2
        labels --> "Event history"
        ylabel --> "Events"
        yticks --> []
        xlabel --> "Time (kyr)"
        xticks --> (x_ticks, Int.(round.(x_ticks ./ 1000)))
        if lowercase(smoothing[1]) ∈ ["gaussian", "normal"]
            seriestype := :line
            lw --> 2
            history = smooth_events(rec, smoothing[2])
            x = Int.(round.(LinRange(-start(rec), -finish(rec), 10000)))
            x, history[Int.(round.(Int, x .+ start(rec) .+ 1))]
        elseif lowercase(smoothing[1]) ∈ ["movavg", "movmean", "moving average", "moving mean"]
            seriestype := :line
            lw --> 2
            history = movmean_events(-rec.events .+ span(rec), span(rec), smoothing[2])
            x = Int.(round.(LinRange(-start(rec), -finish(rec), 10000)))
            x, history[Int.(round.(x .+ start(rec) .+ 1))]
        else
            line := :stem
            marker := :none
            -rec.events, ones(n_events(rec))
        end
    end
end

#----------------- KS plot ------------------
struct KSplot
    model::Model
    rec::Record
    f::Union{Nothing,Interp}
end
"""
Plot recipe for the Kolmogorov-Smirnov plot.
Given a `model` and a `Record`, plot the corresponding KS-plot.
"""
ksplot(model::String, rec::Record; kw...) =
    plot(KSplot(str2model(model), rec, nothing); kw...)
ksplot(model::String, rec::Record, f::Interp; kw...) =
    plot(KSplot(str2model(model), rec, f); kw...)
ksplot!(model::String, rec::Record; kw...) =
    plot!(KSplot(str2model(model), rec, nothing); kw...)
ksplot!(model::String, rec::Record, f::Interp; kw...) =
    plot!(KSplot(str2model(model), rec, f); kw...)

@recipe function f(ks::KSplot; confidence=95, n_sims=1000)
    model = ks.model
    rec = ks.rec
    f = ks.f
    bootstrap_results = fit_test(model, KS(), rec, f, n_sims=n_sims)
    dists = sort(bootstrap_results.sim_dists)
    if (confidence <= 0) || (confidence >= 100)
        confidence = 95
    end
    percentile = dists[end-floor(Int, n_sims * (100 - confidence) / 100)]
    inter_transf = sort(diff(time_transform(bootstrap_results.params, rec, f)))
    M = inter_transf[end-1] * 1.2
    inter_transf = [0; inter_transf; M]
    exp_cdf(t) = 1.0 - exp(-t)
    title --> @sprintf "KS-plot - p-value = %.3g%%" 100 * bootstrap_results.p
    size --> (1200, 400)
    bottom_margin --> 0.7Plots.cm
    left_margin --> 0.7Plots.cm
    legend --> :bottomright
    xlabel --> "Transformed interevent times"
    ylabel --> "Cummulative distribution"
    xlims --> (0, 4)
    @series begin
        line := :steppre
        labels --> "Observed"
        seriescolor --> :royalblue
        lw --> 2
        inter_transf, (0:n_events(rec)) ./ n_events(rec)
    end
    @series begin
        labels --> "Reference"
        linestyle --> :dash
        seriescolor --> :turquoise4
        inter_transf, exp_cdf.(inter_transf)
    end
    @series begin
        labels --> ["$(confidence)% confidence" ""]
        linestyle --> :dashdot
        seriescolor --> :red3
        inter_transf, [(exp_cdf.(inter_transf) .+ percentile) (exp_cdf.(inter_transf) .- percentile)]
    end
end

###################### Auxiliary functions ########################
function smooth_events(rec::Record, σ::Number)
    if σ <= 0
        return events_to_array(rec)
    else
        history = events_to_array(rec)
        σ3 = Int(ceil(3 * σ))
        normalized_pdf = pdf.(Normal(0, σ), -σ3:σ3)
        normalized_pdf ./= maximum(normalized_pdf)
        history = conv(history, normalized_pdf)
        history = history[σ3:end-σ3-1]
    end
    return history
end

function movmean_events(events::Vector{Float64}, T::Float64, window_width::Number)
    if window_width == 0
        window_width = round((2 * T / length(events)) / 10000) * 10000
    end
    return map(x -> sum((events .>= x) .& (events .<= x + window_width)) / window_width, 0:T)
end
