using PointProcessTools
using Test
import PointProcessTools: get_xs, get_ys, distance

@testset "Record" begin
    rec = Record([1, 4, 9 // 2, 3 // 2, 8])
    @test (n_events(rec) == 5) && (eltype(rec.events) <: AbstractFloat)
    @test (interval(rec) == (0, 8)) && (span(rec) == 8) && (typeof(rec.start) <: AbstractFloat)
    @test Record("./record.csv").events == collect(1:9)
    @test Record("./record.csv", Prop1=["a", "c"], Prop2=["y"]).events == [2, 8]
end

@testset "Proxy" begin
    f = Proxy([0, 10], [1, 1])
    int_f = collect(10:-1:0)
    @test integral(f)(collect(0:10)) ≈ int_f
    @test ∫(f) ≈ 10
    f = Proxy("./proxy.csv", 1, 9, period=1)
    @test get_xs(f) == [1; 1.5:8.5; 9]
    @test get_ys(f) == reverse([0.5, 0, 1, 0, 1, 0, 1, 0, 1, 0.5])
end

@testset "Simulations" begin
    rec = Record("./record.csv")
    f = Proxy("./proxy.csv")
    p_hp = ParametersHP(1)
    p_ip = ParametersIP(1, 1)
    p_hh = ParametersHH(1, 1, 2)
    p_ih = ParametersIH(1, 1, 1, 2)
    @test simulate(p_hp, interval(rec)..., f) isa Vector{<:AbstractFloat}
    @test simulate(p_ip, interval(rec)..., f) isa Vector{<:AbstractFloat}
    @test simulate(p_hh, interval(rec)..., f) isa Vector{<:AbstractFloat}
    @test simulate(p_ih, interval(rec)..., f) isa Vector{<:AbstractFloat}
end

@testset "Estimations" begin
    rec = Record("./record.csv")
    f = Proxy("./proxy.csv")
    @test estimate("hp", rec, f) isa ParametersHP
    @test estimate("ip", rec, f) isa ParametersIP
    @test estimate("hh", rec, f) isa ParametersHH
    @test estimate("ih", rec, f) isa ParametersIH
end

@testset "Time transforms" begin
    rec = Record(collect(2:2:12), 2, 12)
    f = Proxy([2, 7, 12], [0, 1, 0], 2, 12)
    μ = rand() * 2
    γ = rand() * 2
    α = rand() * 2
    β = α * (rand() + 1.05)
    ∫base = μ .* collect(0:2:10)
    ∫f = vcat(([0, 2, 4] .^ 2) .* (γ / 10),
        (5 * γ) .- (((10 .- [6, 8, 10]) .^ 2) .* (γ / 10)))
    ∫activation = (α / β) .* (1 .- exp.(-β .* collect(10.0:-2.0:0.0)))
    ∫self = [sum(∫activation[i:end]) for i in 1:6]
    ∫self .= ∫self[1] .- ∫self
    paramsHP = ParametersHP(μ)
    @test time_transform(paramsHP, rec) ≈ ∫base
    paramsIP = ParametersIP(μ, γ)
    @test time_transform(paramsIP, rec, f) ≈ ∫base .+ ∫f
    paramsHH = ParametersHH(μ, α, β)
    @test time_transform(paramsHH, rec) ≈ ∫base .+ ∫self
    paramsIH = ParametersIH(μ, γ, α, β)
    @test time_transform(paramsIH, rec, f) ≈ ∫base .+ ∫f .+ ∫self
end

@testset "Distances" begin
    rec = [0, 1, 2, 3, 4, 5, 7, 9]
    @test distance("ks", rec) == 1 - exp(-1)
    @test distance("ksu", rec, 10) == 0.25
    # FIX: Implement test for LP distance
end

@testset "CIFs" begin
    p_hp = ParametersHP(0.75)
    p_ip = ParametersIP(0.75, 0.5)
    p_hh = ParametersHH(0.75, 1, 1.5)
    p_ih = ParametersIH(0.75, 0.5, 1, 1.5)
    xs = [0, 0.5, 1.5, 2.5, 5]
    rec = Record([1, 2, 3, 4], 5)
    f = Proxy([0, 1, 2, 3, 4, 5], [0, 1, 0, 1, 0, 1])
    @test CIF(p_hp, rec)(xs) ≈ fill(0.75, 5)
    @test ∫CIF(p_hp, rec) ≈ 5 * 0.75
    @test CIF(p_ip, rec, f)(xs) ≈ 0.75 .+ (0.5 .* [0, 0.5, 0.5, 0.5, 1])
    @test ∫CIF(p_ip, rec, f) ≈ (5 * 0.75) + (0.5 * 2.5)
    @test isapprox(CIF(p_hh, rec)(xs), 0.75 .+
                                       [0.28650497723120244, 0.6065310415580695, 0.6012835231588881, 0.577765777302879, 0.0],
        atol=0.01)
    @test ∫CIF(p_hh, rec) ≈ (5 * 0.75) + 2.4756633485125317
    @test isapprox(CIF(p_ih, rec, f)(xs), 0.75 .+ (0.5 .* [0, 0.5, 0.5, 0.5, 1]) .+
                                          [0.28650497723120244, 0.6065310415580695, 0.6012835231588881, 0.577765777302879, 0.0],
        atol=0.01)
    @test ∫CIF(p_ih, rec, f) ≈ (5 * 0.75) + (2.5 * 0.5) + 2.4756633485125317
end
